import { Http, XHRBackend, RequestOptions, Response } from "@angular/http";
import { Observable } from "rxjs";
import { Login } from '../util/login';
export declare class HttpClientService extends Http {
    private loginUtil;
    constructor(backend: XHRBackend, defaultOptions: RequestOptions, loginUtil: Login);
    put(url: string, body: any, options?: RequestOptions): Observable<Response>;
    post(url: string, body: any, options?: RequestOptions): Observable<Response>;
    get(url: string, options?: RequestOptions): Observable<Response>;
    delete(url: string, options?: RequestOptions): Observable<Response>;
    /**
    * Do the request and if the token expires, the method refreshs the token.
    *
    * @param method The HTTP method.
    * @param url The URL to do the request.
    * @param options The request options with headers.
    * @param body The JSON to put in the body request.
    */
    private doRequest(method, url, options?, body?);
    /**
     * Get the request to do.
     *
     * @param method The HTTP method.
     * @param url The URL to do the request.
     * @param options The request options with headers.
     * @param body The JSON to put in the body request.
     */
    private getRequest(method, url, options?, body?);
    /**
     * Do the call to refresh the token.
     */
    private doRefreshToken();
    /**
     * Throw the error of refreshing the token and redirect to login.
     */
    private throwRefreshToken();
    /**
     * Update tje token information in the local storage.
     *
     * @param response The JSON OAuth 2.0 response.
     */
    private updateTokenInfo(response);
}
