"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var http_1 = require("@angular/http");
var rxjs_1 = require("rxjs");
var app_settings_1 = require("../app-settings");
var request_options_util_1 = require("../util/request.options.util");
var messages_constants_1 = require("../util/messages.constants");
var local_storage_1 = require("../local-storage");
var login_1 = require("../util/login");
var HttpClientService = (function (_super) {
    __extends(HttpClientService, _super);
    function HttpClientService(backend, defaultOptions, loginUtil) {
        var _this = _super.call(this, backend, defaultOptions) || this;
        _this.loginUtil = loginUtil;
        return _this;
    }
    HttpClientService.prototype.put = function (url, body, options) {
        return this.doRequest(http_1.RequestMethod.Put, url, options, body);
    };
    HttpClientService.prototype.post = function (url, body, options) {
        return this.doRequest(http_1.RequestMethod.Post, url, options, body);
    };
    HttpClientService.prototype.get = function (url, options) {
        return this.doRequest(http_1.RequestMethod.Get, url, options);
    };
    HttpClientService.prototype.delete = function (url, options) {
        return this.doRequest(http_1.RequestMethod.Delete, url, options);
    };
    /**
    * Do the request and if the token expires, the method refreshs the token.
    *
    * @param method The HTTP method.
    * @param url The URL to do the request.
    * @param options The request options with headers.
    * @param body The JSON to put in the body request.
    */
    HttpClientService.prototype.doRequest = function (method, url, options, body) {
        var _this = this;
        var request = this.getRequest(method, url, options, body);
        return _super.prototype.request.call(this, request).catch(function (error) {
            if (error.status === 401) {
                console.log('Refreshing token ...');
                return _this.doRefreshToken().flatMap(function (response) {
                    console.log('Refreshing token ... OK!');
                    _this.updateTokenInfo(response.json());
                    return _this.doRequest(method, url, request_options_util_1.RequestOptionsUtil.setAccessToken(options), body);
                }).catch(function (error) {
                    console.log('Refreshing token ... Error!');
                    console.log(error);
                    return _this.throwRefreshToken();
                });
            }
            else {
                return rxjs_1.Observable.throw(error);
            }
        });
    };
    /**
     * Get the request to do.
     *
     * @param method The HTTP method.
     * @param url The URL to do the request.
     * @param options The request options with headers.
     * @param body The JSON to put in the body request.
     */
    HttpClientService.prototype.getRequest = function (method, url, options, body) {
        options.body = body;
        var request = new http_1.Request(options);
        request.method = method;
        request.url = url;
        return request;
    };
    /**
     * Do the call to refresh the token.
     */
    HttpClientService.prototype.doRefreshToken = function () {
        var header = { 'Content-Type': 'application/json', 'Authorization': 'Basic ' + app_settings_1.AppSettings.AUTH };
        var headers = new http_1.Headers(header);
        var options = new http_1.RequestOptions({ headers: headers });
        var refreshToken = local_storage_1.WpsLocalStorage.getItem('refresh_token');
        return _super.prototype.post.call(this, app_settings_1.AppSettings.endPointRefreshToken(refreshToken), JSON.stringify(''), options);
    };
    /**
     * Throw the error of refreshing the token and redirect to login.
     */
    HttpClientService.prototype.throwRefreshToken = function () {
        this.loginUtil.tokenCheck(messages_constants_1.MessageConstants.SESSION_EXPIRED);
        local_storage_1.WpsLocalStorage.setItem('refresh_token_expired', 'true');
        return rxjs_1.Observable.throw({});
    };
    /**
     * Update tje token information in the local storage.
     *
     * @param response The JSON OAuth 2.0 response.
     */
    HttpClientService.prototype.updateTokenInfo = function (response) {
        console.dir(response);
        local_storage_1.WpsLocalStorage.setItem('token', response.access_token);
        local_storage_1.WpsLocalStorage.setItem('access_token', response.access_token);
        local_storage_1.WpsLocalStorage.setItem('token_type', response.token_type);
        local_storage_1.WpsLocalStorage.setItem('refresh_token', response.refresh_token);
        local_storage_1.WpsLocalStorage.setItem('expires_in', response.expires_in);
    };
    HttpClientService = __decorate([
        core_1.Injectable(),
        __metadata("design:paramtypes", [http_1.XHRBackend, http_1.RequestOptions, login_1.Login])
    ], HttpClientService);
    return HttpClientService;
}(http_1.Http));
exports.HttpClientService = HttpClientService;
//# sourceMappingURL=http.client.js.map