"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var http_1 = require("@angular/http");
var http_client_1 = require("./http.client");
var app_settings_1 = require("../../app/app-settings");
var ng2_translate_1 = require("ng2-translate");
var Rx_1 = require("rxjs/Rx");
require("rxjs/add/operator/map");
require("rxjs/add/operator/catch");
var local_storage_1 = require("../local-storage");
var login_1 = require("../util/login");
var Service = (function () {
    function Service(http, login, translateService) {
        this.http = http;
        this.login = login;
        this.translateService = translateService;
        if (app_settings_1.AppSettings.DEBUG) {
            this.setHeader(null, false);
        }
        else {
            var header = { 'Content-Type': 'application/json' };
            this.setHeader(header, true);
        }
        this.body = '';
    }
    Service.prototype.get = function (url, json) {
        var _this = this;
        if (json === void 0) { json = true; }
        return this.http.get(url, this.getHeader)
            .map(function (res) {
            // Get Response
            if (json) {
                return res.json();
            }
            else {
                return res;
            }
        })
            .catch(function (error) {
            _this.login.tokenCheck(error.json().error);
            _this.showError(error.json()['errorCode']);
            return Rx_1.Observable.throw(error || 'Server error');
        });
    };
    Service.prototype.post = function (url, json, silent) {
        var _this = this;
        if (json === void 0) { json = true; }
        if (silent === void 0) { silent = true; }
        return this.http.post(url, this.getBody, this.getHeader)
            .map(function (res) {
            // Get Response
            if (json) {
                return res.json();
            }
            else {
                return res;
            }
        })
            .catch(function (error) {
            _this.login.tokenCheck(error.json().error);
            _this.showError(error.json()['errorCode']);
            return Rx_1.Observable.throw(error || 'Server error');
        });
    };
    Service.prototype.put = function (url, json) {
        var _this = this;
        if (json === void 0) { json = true; }
        return this.http.put(url, this.getBody, this.getHeader)
            .map(function (res) {
            // Get Response
            if (json) {
                return res.json();
            }
            else {
                return res;
            }
        })
            .catch(function (error) {
            _this.login.tokenCheck(error.json().error);
            _this.showError(error.json()['errorCode']);
            return Rx_1.Observable.throw(error || 'Server error');
        });
    };
    Service.prototype.delete = function (url, json) {
        var _this = this;
        if (json === void 0) { json = true; }
        return this.http.delete(url, this.getHeader)
            .map(function (res) {
            // Get Response
            if (json) {
                return res.json();
            }
            else {
                return res;
            }
        })
            .catch(function (error) {
            _this.login.tokenCheck(error.json().error);
            _this.showError(error.json()['errorCode']);
            return Rx_1.Observable.throw(error || 'Server error');
        });
    };
    Service.prototype.setHeader = function (header, authorization) {
        if (header === void 0) { header = null; }
        if (authorization === void 0) { authorization = true; }
        // Set Authorization
        if (authorization && !app_settings_1.AppSettings.DEBUG) {
            if (local_storage_1.WpsLocalStorage.getItem('token_type') == null) {
                header.Authorization = app_settings_1.AppSettings.authorizationTemporary;
            }
            else {
                header.Authorization = local_storage_1.WpsLocalStorage.getItem('token_type') + ' ' + local_storage_1.WpsLocalStorage.getItem('access_token');
            }
        }
        var headers = new http_1.Headers(header);
        this.header = new http_1.RequestOptions({ headers: headers });
    };
    Object.defineProperty(Service.prototype, "getHeader", {
        get: function () {
            return this.header;
        },
        enumerable: true,
        configurable: true
    });
    Service.prototype.setBody = function (body) {
        this.body = JSON.stringify(body);
    };
    Service.prototype.setBodyStr = function (str) {
        this.body = str;
    };
    Object.defineProperty(Service.prototype, "getBody", {
        get: function () {
            return this.body;
        },
        enumerable: true,
        configurable: true
    });
    Service.prototype.showError = function (error) {
        local_storage_1.WpsLocalStorage.setItem('errorCode', error);
    };
    Service = __decorate([
        core_1.Injectable(),
        __metadata("design:paramtypes", [http_client_1.HttpClientService, login_1.Login, ng2_translate_1.TranslateService])
    ], Service);
    return Service;
}());
exports.Service = Service;
//# sourceMappingURL=service.js.map