import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/Rx';
import { Station, StationDetail, LiveSubscriber, LiveMqttPacket, LiveEvents, LiveCommandResponse, StationCommand, LiveCommandResponses, LiveStationScreenShot } from '../../../app/models/index';
import { AppSettings } from '../../../app/app-settings';
import { LiveMqttDataPacket } from '../../models/live-operator';
import { Service } from '../service';
import { Subject } from 'rxjs/Rx';

@Injectable()
export class LiveOperatorService {
    liveSubscriberId : string;
    mqttSubject : Subject<LiveMqttPacket> = new Subject();

    constructor(private service: Service) {
    }
  
    subscriber() : Observable<LiveSubscriber>{
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.post(AppSettings.endPointLiveOperatorSubscriber());
    }
  
    hearbeat(id:string) : Observable<LiveSubscriber>{
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.put(AppSettings.endPointLiveOperatorUnsubscriber(id));
    }
  
    unsubscriber(id:string) : Observable<any> {
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.delete(AppSettings.endPointLiveOperatorUnsubscriber(id));     
    }

    getAll(): Observable<LiveMqttDataPacket[]>{
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.get(AppSettings.endPointLiveOperatorGetAll());      
    }
    
    getAllEvents(pageSize : number, pageNumber : number, idCarPark? : string, sortField?: string, sortOrder? : number): Observable<LiveEvents>{
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        if (idCarPark) {
            return this.service.get(AppSettings.endPointLiveOperatorEventsByCarParkGetAll(idCarPark, pageSize, pageNumber));
        } else {
            return this.service.get(AppSettings.endPointLiveOperatorEventsGetAll(pageSize, pageNumber, sortField, sortOrder));
        }
    }

    clearEvent(idCarPark : string, idEvent : number) : Observable<any> {
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.put(AppSettings.endPointLiveOperatorClearEvent(idCarPark, idEvent));
    }

    getEventDetail(idCarPark : string, idEvent : number) : Observable<any> {
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.get(AppSettings.endPointLiveOperatorGetEventDetail(idCarPark, idEvent));
    }
  
    getAllStations(selectedCarpark : string) : Observable<Station[]>{
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.get(AppSettings.endPointLiveOperatorStationsGetAll(selectedCarpark));     
    }
  
    getStationDetail(stationId : string) : Observable<StationDetail> {
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.get(AppSettings.endPointLiveOperatorGetStationDetail(stationId));
    }

    getAllEventsByStation(pageSize : number, pageNumber : number, idStation? : string, idCarPark? : string): Observable<LiveEvents>{
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.get(AppSettings.endPointLiveOperatorEventsByStationGetAll(idCarPark, idStation, pageSize, pageNumber));
    }
    
    sendCommandToStation(idCarPark : string, idStation : string, commandType : string, comment : string, parameters? : any) : Observable<LiveCommandResponse>{
        this.service.setHeader({'Content-Type': 'application/json', 'Live-Operator-Session-Id' : this.liveSubscriberId}, true);
        this.service.setBody(new StationCommand(commandType, comment, parameters));
        return this.service.post(AppSettings.endPointLiveOperatorSendCommand(idCarPark, idStation), true, true);
    }

    getStationCommands(pageNumber : number, pageSize : number) : Observable<LiveCommandResponses>{
        this.service.setHeader({'Content-Type': 'application/json'}, true);
        return this.service.get(AppSettings.endPointLiveOperatorStationCommands(pageSize, pageNumber));
    }

    getStationScreenShot(carParkId : string, stationId : string) : Observable<LiveStationScreenShot> {
        this.service.setHeader({'Content-Type': 'application/json', 'Live-Operator-Session-Id' : this.liveSubscriberId}, true);
        return this.service.post(AppSettings.endPointLiveOperatorStationScreenShot(carParkId, stationId), false);
    }
    
}