import { Injectable } from '@angular/core';
import { Http, Response, Headers, RequestOptions } from '@angular/http';
import { HttpClientService } from './http.client';
import { AppSettings } from '../../app/app-settings';
import { TranslateService } from 'ng2-translate';
import { Observable } from 'rxjs/Rx';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import { WpsLocalStorage } from '../local-storage'
import { Login } from '../util/login';

@Injectable()
export class Service {
    private header: RequestOptions;
    private body: string;

    constructor(private http: HttpClientService, private login: Login, public translateService : TranslateService) {
        if (AppSettings.DEBUG) {
            this.setHeader(null, false);
        } else {
            let header = { 'Content-Type': 'application/json' };
            this.setHeader(header, true);
        }
        this.body = '';
    }

    public get(url: string, json: boolean = true): any {
        return this.http.get(url, this.getHeader)
            .map((res: Response) => {
                // Get Response
                if (json) {
                    return res.json();
                } else {
                    return res;
                }
            })
            .catch((error: any) => {
                this.login.tokenCheck(error.json().error);
                this.showError(error.json()['errorCode']);
                return Observable.throw(error || 'Server error')
            });
    }

    public post(url: string, json: boolean = true, silent: boolean = true): any {
        return this.http.post(url, this.getBody, this.getHeader)
            .map((res: Response) => {
                // Get Response
                if (json) {
                    return res.json();
                } else {
                    return res;
                }
            })
            .catch((error: any) => {
                this.login.tokenCheck(error.json().error);
                this.showError(error.json()['errorCode']);
                return Observable.throw(error || 'Server error')
            });
    }

    public put(url: string, json: boolean = true): any {
        return this.http.put(url, this.getBody, this.getHeader)
            .map((res: Response) => {
                // Get Response
                if (json) {
                    return res.json();
                } else {
                    return res;
                }
            })
            .catch((error: any) => {
                this.login.tokenCheck(error.json().error);
                this.showError(error.json()['errorCode']);
                return Observable.throw(error || 'Server error')
            });
    }

    public delete(url: string, json: boolean = true): any {
        return this.http.delete(url, this.getHeader)
            .map((res: Response) => {
                // Get Response
                if (json) {
                    return res.json();
                } else {
                    return res;
                }
            })
            .catch((error: any) => {
                this.login.tokenCheck(error.json().error);
                this.showError(error.json()['errorCode']);
                return Observable.throw(error || 'Server error')
            });
    }

    public setHeader(header: any = null, authorization: boolean = true): void {
        // Set Authorization
        if (authorization && !AppSettings.DEBUG) {
            if (WpsLocalStorage.getItem('token_type') == null) {
                header.Authorization = AppSettings.authorizationTemporary;
            } else {
                header.Authorization = WpsLocalStorage.getItem('token_type') + ' ' + WpsLocalStorage.getItem('access_token');
            }
        }
        let headers = new Headers(header);
        this.header = new RequestOptions({ headers: headers });
    }

    public get getHeader(): RequestOptions {
        return this.header;
    }


    public setBody(body): void {
        this.body = JSON.stringify(body);
    }
    
    public setBodyStr(str) {
        this.body = str;   
    }

    public get getBody(): any {
        return this.body;
    }

    public showError(error : string) {
        WpsLocalStorage.setItem('errorCode', error);
    }
}